@@ -592,7 +592,7 @@ var app = window.Yancy = new Vue({
 
                 for ( var propKey in definition.properties ) {
                     var prop = definition.properties[ propKey ];
-                    if ( prop[ 'x-html-field' ] && definitions.properties[ prop['x-html-field'] ] ) {
+                    if ( prop[ 'x-html-field' ] && definition.properties[ prop['x-html-field'] ] ) {
                         definition.properties[ prop['x-html-field' ] ][ 'x-hidden' ] = true;
                     }
                 }
