@@ -1,5 +1,5 @@
 package Yancy::Backend::Role::Relational;
-our $VERSION = '1.062';
+our $VERSION = '1.063';
 # ABSTRACT: A role to give a relational backend relational capabilities
 
 #pod =head1 SYNOPSIS
@@ -183,7 +183,12 @@ requires qw(
 
 sub new {
     my ( $class, $backend, $schema ) = @_;
-    if ( !ref $backend ) {
+    if ( blessed $backend && !$backend->isa( $class->mojodb_class ) ) {
+        # This prevents random objects being sent to us, like the
+        # Mojo::MySQL version 0.01 that may somehow be installed...
+        die "$class requires a " . $class->mojodb_class . ' object. Got a ' . blessed( $backend ) . ' object instead';
+    }
+    elsif ( !ref $backend ) {
         my $found = (my $connect = $backend) =~ s#^.*?:##;
         $backend = $class->mojodb_class->new( $found ? $class->mojodb_prefix.":$connect" : () );
     }
@@ -451,7 +456,7 @@ Yancy::Backend::Role::Relational - A role to give a relational backend relationa
 
 =head1 VERSION
 
-version 1.062
+version 1.063
 
 =head1 SYNOPSIS
 
