@@ -1,5 +1,5 @@
 package Yancy::Plugin::Editor;
-our $VERSION = '1.062';
+our $VERSION = '1.063';
 # ABSTRACT: Yancy content editor, admin, and management application
 
 #pod =head1 SYNOPSIS
@@ -84,6 +84,17 @@ our $VERSION = '1.062';
 #pod
 #pod The title of the page, shown in the title bar and the page header. Defaults to C<Yancy>.
 #pod
+#pod =head2 host
+#pod
+#pod The host to use for the generated OpenAPI spec. Defaults to the current system's hostname
+#pod (via L<Sys::Hostname>).
+#pod
+#pod =head2 info
+#pod
+#pod An OpenAPI info object, as a Perl hashref. See L<the OpenAPI 2.0
+#pod spec|https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#infoObject>
+#pod for what keys are allowed in this hashref.
+#pod
 #pod =head1 HELPERS
 #pod
 #pod =head2 yancy.editor.include
@@ -499,6 +510,7 @@ sub _openapi_spec_from_schema {
 
         $paths{ '/' . $schema_name } = {
             get => {
+                description => $self->app->l( 'OpenAPI list description' ),
                 parameters => [
                     { '$ref' => '#/parameters/%24limit' },
                     { '$ref' => '#/parameters/%24offset' },
@@ -522,25 +534,29 @@ sub _openapi_spec_from_schema {
                 ],
                 responses => {
                     200 => {
-                        description => 'List of items',
+                        description => $self->app->l( 'OpenAPI list response' ),
                         schema => {
                             type => 'object',
                             required => [qw( items total )],
                             properties => {
                                 total => {
                                     type => 'integer',
-                                    description => 'The total number of items available',
+                                    description => $self->app->l( 'OpenAPI list total description' ),
                                 },
                                 items => {
                                     type => 'array',
-                                    description => 'This page of items',
+                                    description => $self->app->l( 'OpenAPI list items description' ),
                                     items => { '$ref' => "#/definitions/" . url_escape $schema_name },
                                 },
+                                offset => {
+                                    type => 'integer',
+                                    description => $self->app->l( 'OpenAPI list offset description' ),
+                                },
                             },
                         },
                     },
                     default => {
-                        description => 'Unexpected error',
+                        description => $self->app->l( 'Unexpected error' ),
                         schema => { '$ref' => '#/definitions/_Error' },
                     },
                 },
@@ -556,14 +572,14 @@ sub _openapi_spec_from_schema {
                 ],
                 responses => {
                     201 => {
-                        description => "Entry was created",
+                        description => $self->app->l( 'OpenAPI create response' ),
                         schema => {
                             '$ref' => '#' . join '/', map { url_escape $_ } 'definitions',
                                       $schema_name, 'properties', @id_fields,
                         },
                     },
                     default => {
-                        description => "Unexpected error",
+                        description => $self->app->l( "Unexpected error" ),
                         schema => { '$ref' => "#/definitions/_Error" },
                     },
                 },
@@ -582,21 +598,21 @@ sub _openapi_spec_from_schema {
             ],
 
             get => {
-                description => "Fetch a single item",
+                description => $self->app->l( 'OpenAPI get description' ),
                 responses => {
                     200 => {
-                        description => "Item details",
+                        description => $self->app->l( 'OpenAPI get response' ),
                         schema => { '$ref' => "#/definitions/" . url_escape $schema_name },
                     },
                     default => {
-                        description => "Unexpected error",
+                        description => $self->app->l( "Unexpected error" ),
                         schema => { '$ref' => '#/definitions/_Error' },
                     }
                 }
             },
 
             $schema->{'x-view'} ? () : (put => {
-                description => "Update a single item",
+                description => $self->app->l( 'OpenAPI update description' ),
                 parameters => [
                     {
                         name => "newItem",
@@ -607,24 +623,24 @@ sub _openapi_spec_from_schema {
                 ],
                 responses => {
                     200 => {
-                        description => "Item was updated",
+                        description => $self->app->l( 'OpenAPI update response' ),
                         schema => { '$ref' => "#/definitions/" . url_escape $schema_name },
                     },
                     default => {
-                        description => "Unexpected error",
+                        description => $self->app->l( "Unexpected error" ),
                         schema => { '$ref' => "#/definitions/_Error" },
                     }
                 }
             },
 
             delete => {
-                description => "Delete a single item",
+                description => $self->app->l( 'OpenAPI delete description' ),
                 responses => {
                     204 => {
-                        description => "Item was deleted",
+                        description => $self->app->l( 'OpenAPI delete response' ),
                     },
                     default => {
-                        description => "Unexpected error",
+                        description => $self->app->l( "Unexpected error" ),
                         schema => { '$ref' => '#/definitions/_Error' },
                     },
                 },
@@ -642,7 +658,7 @@ sub _openapi_spec_from_schema {
         produces => [qw( application/json )],
         definitions => {
             _Error => {
-                title => 'OpenAPI Error Object',
+                title => $self->app->l( 'OpenAPI error object' ),
                 type => 'object',
                 properties => {
                     errors => {
@@ -652,11 +668,11 @@ sub _openapi_spec_from_schema {
                             properties => {
                                 message => {
                                     type => "string",
-                                    description => "Human readable description of the error",
+                                    description => $self->app->l( 'OpenAPI error message' ),
                                 },
                                 path => {
                                     type => "string",
-                                    description => "JSON pointer to the input data where the error occur"
+                                    description => $self->app->l( 'OpenAPI error path' ),
                                 }
                             }
                         }
@@ -683,7 +699,7 @@ Yancy::Plugin::Editor - Yancy content editor, admin, and management application
 
 =head1 VERSION
 
-version 1.062
+version 1.063
 
 =head1 SYNOPSIS
 
@@ -767,6 +783,17 @@ The URL to use for the "Back to Application" link. Defaults to C</>.
 
 The title of the page, shown in the title bar and the page header. Defaults to C<Yancy>.
 
+=head2 host
+
+The host to use for the generated OpenAPI spec. Defaults to the current system's hostname
+(via L<Sys::Hostname>).
+
+=head2 info
+
+An OpenAPI info object, as a Perl hashref. See L<the OpenAPI 2.0
+spec|https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#infoObject>
+for what keys are allowed in this hashref.
+
 =head1 HELPERS
 
 =head2 yancy.editor.include
